@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -15,11 +15,13 @@
 
 #include <KConfigGroup>
 #include <KSharedConfig>
+#include <KWindowConfig>
 #include <QApplication>
 #include <QDialogButtonBox>
 #include <QPushButton>
 #include <QTabWidget>
 #include <QVBoxLayout>
+#include <QWindow>
 
 #include <config/notenetworkconfig.h>
 
@@ -57,7 +59,7 @@ NotesAgentSettingsDialog::NotesAgentSettingsDialog(QWidget *parent)
                                       QStringLiteral(KNOTES_VERSION),
                                       i18n("Notes Agent."),
                                       KAboutLicense::GPL_V2,
-                                      i18n("Copyright (C) 2013-%1 Laurent Montel", QStringLiteral("2022")));
+                                      i18n("Copyright (C) 2013-%1 Laurent Montel", QStringLiteral("2023")));
 
     aboutData.addAuthor(i18n("Laurent Montel"), i18n("Maintainer"), QStringLiteral("montel@kde.org"));
 
@@ -77,20 +79,19 @@ NotesAgentSettingsDialog::~NotesAgentSettingsDialog()
 }
 
 static const char myConfigGroupName[] = "NotesAgentSettingsDialog";
+void NotesAgentSettingsDialog::readConfig()
+{
+    create(); // ensure a window is created
+    windowHandle()->resize(QSize(500, 300));
+    KConfigGroup group(KSharedConfig::openStateConfig(), myConfigGroupName);
+    KWindowConfig::restoreWindowSize(windowHandle(), group);
+    resize(windowHandle()->size()); // workaround for QTBUG-40584
+}
+
 void NotesAgentSettingsDialog::writeConfig()
 {
     KConfigGroup group(KSharedConfig::openStateConfig(), myConfigGroupName);
-
-    const QSize size = group.readEntry("Size", QSize(500, 300));
-    if (size.isValid()) {
-        resize(size);
-    }
-}
-
-void NotesAgentSettingsDialog::readConfig()
-{
-    KConfigGroup group(KSharedConfig::openStateConfig(), myConfigGroupName);
-    group.writeEntry("Size", size());
+    KWindowConfig::saveWindowSize(windowHandle(), group);
     group.sync();
 }
 
