@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -15,6 +15,4 @@ NotesAkonadiTreeModel::NotesAkonadiTreeModel(Akonadi::ChangeRecorder *changeReco
     setItemPopulationStrategy(Akonadi::EntityTreeModel::ImmediatePopulation);
 }
 
-NotesAkonadiTreeModel::~NotesAkonadiTreeModel()
-{
-}
+NotesAkonadiTreeModel::~NotesAkonadiTreeModel() = default;
