@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,6 +7,7 @@
 
 #include <QByteArray>
 #include <QDataStream>
+#include <QIODevice>
 
 using namespace NoteShared;
 NoteAlarmAttribute::NoteAlarmAttribute()
@@ -14,9 +15,7 @@ NoteAlarmAttribute::NoteAlarmAttribute()
 {
 }
 
-NoteAlarmAttribute::~NoteAlarmAttribute()
-{
-}
+NoteAlarmAttribute::~NoteAlarmAttribute() = default;
 
 NoteAlarmAttribute *NoteAlarmAttribute::clone() const
 {
