@@ -6,11 +6,17 @@
 
 #pragma once
 
+#include "config-noshared.h"
 #include <KPIMTextEdit/RichTextEditor>
+#if HAVE_TEXT_AUTOCORRECTION_WIDGETS
+namespace TextAutoCorrectionCore
+#else
 namespace TextAutoCorrection
+#endif
 {
 class AutoCorrection;
 }
+
 namespace NoteShared
 {
 class RichTextEditWithAutoCorrectionPrivate;
@@ -25,8 +31,13 @@ public:
     explicit RichTextEditWithAutoCorrection(QWidget *parent = nullptr);
     ~RichTextEditWithAutoCorrection() override;
 
+#if HAVE_TEXT_AUTOCORRECTION_WIDGETS
+    Q_REQUIRED_RESULT TextAutoCorrectionCore::AutoCorrection *autocorrection() const;
+    void setAutocorrection(TextAutoCorrectionCore::AutoCorrection *autocorrect);
+#else
     Q_REQUIRED_RESULT TextAutoCorrection::AutoCorrection *autocorrection() const;
     void setAutocorrection(TextAutoCorrection::AutoCorrection *autocorrect);
+#endif
 
     void setAutocorrectionLanguage(const QString &language);
 
