@@ -536,7 +536,13 @@ void KNoteEdit::slotCurrentCharFormatChanged(const QTextCharFormat &f)
     }
 
     // font changes
-    m_textFont->setFont(f.fontFamily());
+#if QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
+    const QStringList families = f.fontFamilies().toStringList();
+    const auto fontFamily = families.isEmpty() ? QString() : families.constFirst();
+#else
+    const auto fontFamily = f.fontFamily();
+#endif
+    m_textFont->setFont(fontFamily);
     m_textSize->setFontSize((f.fontPointSize() > 0) ? (int)f.fontPointSize() : 10);
 
     m_textBold->setChecked(f.font().bold());
