@@ -5,6 +5,7 @@
 */
 #pragma once
 
+#include "kcmutils_version.h"
 #include <KCModule>
 #include <KViewStateMaintainer>
 namespace Akonadi
@@ -22,7 +23,11 @@ class KCMKNotesSummary : public KCModule
     Q_OBJECT
 
 public:
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
     explicit KCMKNotesSummary(QWidget *parent = nullptr, const QVariantList &args = QVariantList());
+#else
+    explicit KCMKNotesSummary(QObject *parent, const KPluginMetaData &data, const QVariantList &args = QVariantList());
+#endif
 
     void load() override;
     void save() override;
