@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,25 +7,26 @@
 #include "knoteedit.h"
 
 #include <KActionCollection>
-#include <KLineEdit>
 #include <KLocalizedString>
 #include <KToolBar>
+#include <QLineEdit>
 
 #include <KXMLGUIBuilder>
 #include <KXMLGUIFactory>
 
 #include <KConfigGroup>
 #include <KSharedConfig>
+#include <KWindowConfig>
 #include <QAction>
 #include <QDialogButtonBox>
 #include <QHBoxLayout>
 #include <QLabel>
 #include <QPushButton>
 #include <QVBoxLayout>
+#include <QWindow>
 
 KNoteEditDialog::KNoteEditDialog(bool readOnly, QWidget *parent)
     : QDialog(parent)
-    , mOkButton(nullptr)
 {
     init(readOnly);
 }
@@ -64,7 +65,7 @@ void KNoteEditDialog::init(bool readOnly)
     auto label = new QLabel(page);
     label->setText(i18nc("@label popup note name", "Name:"));
     hbl->addWidget(label, 0);
-    mTitleEdit = new KLineEdit(page);
+    mTitleEdit = new QLineEdit(page);
     mTitleEdit->setClearButtonEnabled(!readOnly);
     mTitleEdit->setObjectName(QStringLiteral("name"));
     if (!readOnly) {
@@ -116,20 +117,24 @@ void KNoteEditDialog::setReadOnly(bool b)
     mTitleEdit->setEnabled(!b);
 }
 
+namespace
+{
+static const char myKNoteEditDialogName[] = "KNoteEditDialog";
+}
 void KNoteEditDialog::readConfig()
 {
-    KConfigGroup grp(KSharedConfig::openStateConfig(), "KNoteEditDialog");
-    const QSize size = grp.readEntry("Size", QSize(300, 200));
-    if (size.isValid()) {
-        resize(size);
-    }
+    create(); // ensure a window is created
+    windowHandle()->resize(QSize(300, 200));
+    KConfigGroup group(KSharedConfig::openStateConfig(), myKNoteEditDialogName);
+    KWindowConfig::restoreWindowSize(windowHandle(), group);
+    resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
 
 void KNoteEditDialog::writeConfig()
 {
-    KConfigGroup grp(KSharedConfig::openStateConfig(), "KNoteEditDialog");
-    grp.writeEntry("Size", size());
-    grp.sync();
+    KConfigGroup group(KSharedConfig::openStateConfig(), myKNoteEditDialogName);
+    KWindowConfig::saveWindowSize(windowHandle(), group);
+    group.sync();
 }
 
 QString KNoteEditDialog::text() const
